@@ -11,9 +11,9 @@ from advpowcommon.ui.Banners import HildonBanner
 from advpowcommon.ui.Animation import DITPBCachedAnimator
 from advpowcommon.ui.ToggleControl import ToggleControlMaemo5
 from advpowcommon.util.execn import *
-from advifswlib.util.cacher import *
-from advifswlib.util.config import *
-from advifswlib.util.locale import *
+import advifswlib.util.cacher as cacher
+import advifswlib.util.config as config
+import advifswlib.util.locale as locale
 
 class AbstractInterface():
 
@@ -24,11 +24,11 @@ class AbstractInterface():
     self.__set_status_area_icon = cb_status_area
     self.__show_settings_dialog = cb_show_settings_dialog
     self.__interfaces = {}
-    self.__lcl = get_locale()
+    self.__lcl = locale.get()
     self.interfaces = {}
     self.indication = 'on'
     self.state = {}
-    self.__config = get_config()
+    self.__config = config.get()
     self.pre_init()
     self.__name = self.state['name']
     self.__config_path = 'settings/%s' % (self.__name.lower())
@@ -43,7 +43,7 @@ class AbstractInterface():
     self.__button.tap_and_hold_setup(None, None, 0)
     self.__button.connect('tap-and-hold', self.__button_tap_and_hold)
     self.__button.connect('destroy', self.__destroy)
-    self.__smi_cacher = get_cacher()
+    self.__smi_cacher = cacher.get()
     self.__smi_animator = DITPBCachedAnimator([], self.__button.get_image().set_from_pixbuf, cacher=self.__smi_cacher, time_out=250)
     self.state_control = None
     self.mode_control = None
@@ -53,6 +53,7 @@ class AbstractInterface():
     self.__get_status()
     self.__init_signals()
     self.stop_animation()
+    self.__switch_state(int(self.get_config_value('startup-enable')))
     #print self.__name, self.state['value'], self.state['mode'], self.state['strength']
     #self.__show_switch_dialog()
 
@@ -74,6 +75,12 @@ class AbstractInterface():
   def get_bus(self):
     return self.__bus
 
+  def get_modes(self):
+    return self.state['modes']
+
+  def get_config_value(self, key):
+    return self.__config.get_value('%s/%s' % (self.__config_path, key))
+
   def destroy(self):
     self.__destroy()
 
@@ -177,10 +184,10 @@ class AbstractInterface():
     self.__button.set_value(self.__lcl.get_item(self.state['text'][windex]))
 
   def __button_clicked(self, button=None, user_data=None):
-    return self.__switch(self.__config.get_value('%s/show-state-dialog' % (self.__config_path)))
+    return self.__switch(self.get_config_value('show-state-dialog'))
 
   def __button_tap_and_hold(self, button=None, user_data=None):
-    return self.__switch(not(self.__config.get_value('%s/show-state-dialog' % (self.__config_path))))
+    return self.__switch(not(self.get_config_value('show-state-dialog')))
 
   def __switch(self, show_dialog):
     if not self.__processing:
