@@ -34,7 +34,7 @@ class BTInterface(AbstractInterface):
     'banner': (True, False, True),
     'value': 0,
     'strength': 0,
-    'modes': ('Connectable', 'Discoverable'),
+    'modes': ('bluetooth-connectable', 'bluetooth-discoverable'),
     'mode': 0
     }
     self.interfaces = {'BlueZAdapter': ['org.bluez', self.bt_adapter_path, self.bt_adapter_iface, '', True]}
